================
Slurry-Websocket
================


Credits
-------

Small bits of code and documentation has been copied from the `Trio-Websocket`_ library.





.. _`Trio-Websocket`: https://github.com/HyperionGray/trio-websocket